Enum MprisEvent

pub enum MprisEvent {
    PlayerAttached(MprisPlayer),
    PlayerDetached(PlayerIdentity),
    PlayerPropertiesChanged(PlayerIdentity),
    PlayerSeeked(PlayerIdentity),
    PlayerPosition(PlayerIdentity, Duration),
}
Represents events triggered by changes in an MPRIS media player.

Variants



PlayerAttached(MprisPlayer)

Triggers when a new player has been attached or added. This is the only event that has the MprisPlayer on it. You should add it on state to be managed.



PlayerDetached(PlayerIdentity)

Triggers when an existing player has been detached or removed.



PlayerPropertiesChanged(PlayerIdentity)

Triggers when one of the player’s properties changed.



PlayerSeeked(PlayerIdentity)

Triggers when one of the player’s position changed due to the user manually changing it.



PlayerPosition(PlayerIdentity, Duration)

Triggers when one of the player’s position changed.